KSAdNativeCallBack class

信息流广告回调

Constructors

KSAdNativeCallBack({KSOnShow? onShow, KSOnClick? onClick, KSOnClose? onClose, KSOnFail? onFail})

Properties

hashCode int
The hash code for this object.
no setterinherited
onClick KSOnClick?
getter/setter pair
onClose KSOnClose?
getter/setter pair
onFail KSOnFail?
getter/setter pair
onShow KSOnShow?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited